__version__="4.3.0"
__copyright__="Copyright (c) 2001 - 2021 The SCons Foundation"
__developer__="_reproducible"
__date__="Wed, 15 Dec 2021 05:30:09 +0000"
__buildsys__="_reproducible"
__revision__=""
__build__=""
# make sure compatibility is always in place
import SCons.compat # noqa